@@ -72,9 +72,9 @@ from qutebrowser.keyinput import macros
 from qutebrowser.mainwindow import mainwindow, prompt
 from qutebrowser.misc import (readline, ipc, savemanager, sessions,
                               crashsignal, earlyinit, sql, cmdhistory,
-                              backendproblem)
+                              backendproblem, objects)
 from qutebrowser.utils import (log, version, message, utils, urlutils, objreg,
-                               usertypes, standarddir, error)
+                               usertypes, standarddir, error, qtutils)
 # pylint: disable=unused-import
 # We import those to run the cmdutils.register decorators.
 from qutebrowser.mainwindow.statusbar import command
@@ -104,6 +104,7 @@ def run(args):
     qApp = Application(args)
     qApp.setOrganizationName("qutebrowser")
     qApp.setApplicationName("qutebrowser")
+    qApp.setDesktopFileName("qutebrowser")
     qApp.setApplicationVersion(qutebrowser.__version__)
     qApp.lastWindowClosed.connect(quitter.on_last_window_closed)
 
@@ -129,6 +130,9 @@ def run(args):
         sys.exit(usertypes.Exit.err_ipc)
 
     if server is None:
+        if args.backend is not None:
+            log.init.warning(
+                "Backend from the running instance will be used")
         sys.exit(usertypes.Exit.ok)
     else:
         server.got_args.connect(lambda args, target_arg, cwd:
@@ -181,8 +185,6 @@ def init(args, crash_handler):
     QDesktopServices.setUrlHandler('https', open_desktopservices_url)
     QDesktopServices.setUrlHandler('qute', open_desktopservices_url)
 
-    objreg.get('web-history').import_txt()
-
     log.init.debug("Init done!")
     crash_handler.raise_crashdlg()
 
@@ -349,10 +351,6 @@ def _open_startpage(win_id=None):
 def _open_special_pages(args):
     """Open special notification pages which are only shown once.
 
-    Currently this is:
-      - Quickstart page if it's the first start.
-      - Legacy QtWebKit warning if needed.
-
     Args:
         args: The argparse namespace.
     """
@@ -364,25 +362,30 @@ def _open_special_pages(args):
     tabbed_browser = objreg.get('tabbed-browser', scope='window',
                                 window='last-focused')
 
-    # Quickstart page
+    pages = [
+        # state, condition, URL
+        ('quickstart-done',
+         True,
+         'https://www.qutebrowser.org/quickstart.html'),
 
-    quickstart_done = general_sect.get('quickstart-done') == '1'
+        ('config-migration-shown',
+         os.path.exists(os.path.join(standarddir.config(),
+                                     'qutebrowser.conf')),
+         'qute://help/configuring.html'),
 
-    if not quickstart_done:
-        tabbed_browser.tabopen(
-            QUrl('https://www.qutebrowser.org/quickstart.html'))
-        general_sect['quickstart-done'] = '1'
+        ('webkit-warning-shown',
+         objects.backend == usertypes.Backend.QtWebKit,
+         'qute://warning/webkit'),
 
-    # Setting migration page
+        ('old-qt-warning-shown',
+         not qtutils.version_check('5.9'),
+         'qute://warning/old-qt'),
+    ]
 
-    needs_migration = os.path.exists(
-        os.path.join(standarddir.config(), 'qutebrowser.conf'))
-    migration_shown = general_sect.get('config-migration-shown') == '1'
-
-    if needs_migration and not migration_shown:
-        tabbed_browser.tabopen(QUrl('qute://help/configuring.html'),
-                               background=False)
-        general_sect['config-migration-shown'] = '1'
+    for state, condition, url in pages:
+        if general_sect.get(state) != '1' and condition:
+            tabbed_browser.tabopen(QUrl(url), background=False)
+            general_sect[state] = '1'
 
 
 def on_focus_changed(_old, new):
@@ -445,13 +448,10 @@ def _init_modules(args, crash_handler):
 
         log.init.debug("Initializing web history...")
         history.init(qApp)
-    except sql.SqlError as e:
-        if e.environmental:
-            error.handle_fatal_exc(e, args, 'Error initializing SQL',
-                                   pre_text='Error initializing SQL')
-            sys.exit(usertypes.Exit.err_init)
-        else:
-            raise
+    except sql.SqlEnvironmentError as e:
+        error.handle_fatal_exc(e, args, 'Error initializing SQL',
+                               pre_text='Error initializing SQL')
+        sys.exit(usertypes.Exit.err_init)
 
     log.init.debug("Initializing completion...")
     completiondelegate.init()
