@@ -145,7 +145,7 @@ class GreasemonkeyScript:
 
 
 @attr.s
-class MatchingScripts(object):
+class MatchingScripts:
 
     """All userscripts registered to run on a particular url."""
 
@@ -234,7 +234,7 @@ class GreasemonkeyManager(QObject):
             if not os.path.isfile(script_filename):
                 continue
             script_path = os.path.join(scripts_dir, script_filename)
-            with open(script_path, encoding='utf-8') as script_file:
+            with open(script_path, encoding='utf-8-sig') as script_file:
                 script = GreasemonkeyScript.parse(script_file.read())
                 if not script.name:
                     script.name = script_filename
