@@ -28,6 +28,10 @@ class CertificateErrorWrapper(usertypes.AbstractCertificateErrorWrapper):
 
     """A wrapper over a QWebEngineCertificateError."""
 
+    def __init__(self, error):
+        super().__init__(error)
+        self.ignore = False
+
     def __str__(self):
         return self._error.errorDescription()
 
@@ -37,5 +41,8 @@ class CertificateErrorWrapper(usertypes.AbstractCertificateErrorWrapper):
                                         self._error.error()),
             string=str(self))
 
+    def url(self):
+        return self._error.url()
+
     def is_overridable(self):
         return self._error.isOverridable()
