@@ -1,6 +1,6 @@
 # vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
 
-# Copyright 2014-2016 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# Copyright 2014-2018 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
 # This file is part of qutebrowser.
 #
@@ -22,11 +22,11 @@
 
 import os.path
 
+from PyQt5.QtNetwork import QNetworkRequest
+
 from qutebrowser.utils import log
 from qutebrowser.browser.webkit import rfc6266
 
-from PyQt5.QtNetwork import QNetworkRequest
-
 
 def parse_content_disposition(reply):
     """Parse a content_disposition header.
@@ -57,9 +57,7 @@ def parse_content_disposition(reply):
             is_inline = content_disposition.is_inline()
     # Then try to get filename from url
     if not filename:
-        path = reply.url().path()
-        if path is not None:
-            filename = path.rstrip('/')
+        filename = reply.url().path().rstrip('/')
     # If that fails as well, use a fallback
     if not filename:
         filename = 'qutebrowser-download'
