@@ -1,6 +1,6 @@
 # vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
 
-# Copyright 2014-2017 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# Copyright 2014-2018 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
 # This file is part of qutebrowser.
 #
@@ -138,10 +138,10 @@ class CompletionItemDelegate(QStyledItemDelegate):
 
         self._painter.translate(text_rect.left(), text_rect.top())
         self._get_textdoc(index)
-        self._draw_textdoc(text_rect)
+        self._draw_textdoc(text_rect, index.column())
         self._painter.restore()
 
-    def _draw_textdoc(self, rect):
+    def _draw_textdoc(self, rect, col):
         """Draw the QTextDocument of an item.
 
         Args:
@@ -156,7 +156,9 @@ class CompletionItemDelegate(QStyledItemDelegate):
         elif not self._opt.state & QStyle.State_Enabled:
             color = config.val.colors.completion.category.fg
         else:
-            color = config.val.colors.completion.fg
+            colors = config.val.colors.completion.fg
+            # if multiple colors are set, use different colors per column
+            color = colors[col % len(colors)]
         self._painter.setPen(color)
 
         ctx = QAbstractTextDocumentLayout.PaintContext()
@@ -201,9 +203,9 @@ class CompletionItemDelegate(QStyledItemDelegate):
             columns_to_filter = index.model().columns_to_filter(index)
             if index.column() in columns_to_filter and pattern:
                 repl = r'<span class="highlight">\g<0></span>'
-                text = re.sub(re.escape(pattern).replace(r'\ ', r'|'),
-                              repl, html.escape(self._opt.text),
-                              flags=re.IGNORECASE)
+                pat = html.escape(re.escape(pattern)).replace(r'\ ', r'|')
+                txt = html.escape(self._opt.text)
+                text = re.sub(pat, repl, txt, flags=re.IGNORECASE)
                 self._doc.setHtml(text)
             else:
                 self._doc.setPlainText(self._opt.text)
