@@ -225,16 +225,17 @@ class TabWidget(QTabWidget):
         non-visible. To avoid flickering, disable repaint updates whlie we
         work.
         """
-        toggle = self.count() > 10
+        bar = self.tabBar()
+        toggle = self.count() > 10 and bar.isVisible()
         if toggle:
-            self.setUpdatesEnabled(False)
-            self.setVisible(False)
+            bar.setUpdatesEnabled(False)
+            bar.setVisible(False)
 
         yield
 
         if toggle:
-            self.setVisible(True)
-            self.setUpdatesEnabled(True)
+            bar.setVisible(True)
+            bar.setUpdatesEnabled(True)
 
     def update_tab_titles(self):
         """Update all texts."""
