@@ -29,6 +29,8 @@ import ipaddress
 import fnmatch
 import urllib.parse
 
+from PyQt5.QtCore import QUrl
+
 from qutebrowser.utils import utils, qtutils
 
 
@@ -179,6 +181,15 @@ class UrlPattern:
             assert self._host is None
             return
 
+        if parsed.netloc.startswith('['):
+            # Using QUrl parsing to minimize ipv6 addresses
+            url = QUrl()
+            url.setHost(parsed.hostname)
+            if not url.isValid():
+                raise ParseError(url.errorString())
+            self._host = url.host()
+            return
+
         # FIXME what about multiple dots?
         host_parts = parsed.hostname.rstrip('.').split('.')
         if host_parts[0] == '*':
